package com.ruoyi.ems.mapper;

import java.util.List;

import com.ruoyi.ems.domain.ElecValencyHourStrategy;

/**
 * 电价策略小时Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-23
 */
public interface ElecValencyHourStrategyMapper {
    /**
     * 查询电价策略小时
     *
     * @param id 电价策略小时主键
     * @return 电价策略小时
     */
    ElecValencyHourStrategy selectElecValencyStrategyHourById(Long id);

    /**
     * 查询电价策略小时列表
     *
     * @param elecValencyStrategyHour 电价策略小时
     * @return 电价策略小时集合
     */
    List<ElecValencyHourStrategy> selectElecValencyStrategyHourList(ElecValencyHourStrategy elecValencyStrategyHour);

    /**
     * 新增电价策略小时
     *
     * @param elecValencyStrategyHour 电价策略小时
     * @return 结果
     */
    int insertElecValencyStrategyHour(ElecValencyHourStrategy elecValencyStrategyHour);

    /**
     * 批量新增电价策略小时
     *
     * @param elecValencyStrategyHours 电价策略小时列表
     * @return 结果
     */
    int insertElecValencyStrategyHourBatch(List<ElecValencyHourStrategy> elecValencyStrategyHours);

    /**
     * 修改电价策略小时
     *
     * @param elecValencyStrategyHour 电价策略小时
     * @return 结果
     */
    int updateElecValencyStrategyHour(ElecValencyHourStrategy elecValencyStrategyHour);

    /**
     * 删除电价策略小时
     *
     * @param id 电价策略小时主键
     * @return 结果
     */
    int deleteElecValencyStrategyHourById(Long id);

    /**
     * 删除电价策略小时
     *
     * @param strategyCode 策略编码
     * @return 结果
     */
    int deleteElecValencyStrategyHourByStrategy(String strategyCode);

    /**
     * 批量删除电价策略小时
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteElecValencyStrategyHourByIds(Long[] ids);
}
